@@ -113,23 +113,25 @@ describe("low level http 1 connection operations", function()
 		local function test(chunk)
 			local s, c = new_pair(1.1)
 			s = s:take_socket()
-			assert(s:write(chunk, "\r\n"))
-			assert(s:flush())
-			assert.same(ce.EILSEQ, select(3, c:read_request_line()))
+			assert(s:xwrite(chunk, "n", TEST_TIMEOUT))
 			s:close()
+			assert.same(ce.EILSEQ, select(3, c:read_request_line(TEST_TIMEOUT)))
 			c:close()
 		end
-		test("invalid request line")
-		test(" / HTTP/1.1")
-		test("HTTP/1.1")
-		test("GET HTTP/1.0")
-		test("GET  HTTP/1.0")
-		test("GET HTTP/1.0")
-		test("GET / HTP/1.1")
-		test("GET / HTTP 1.1")
-		test("GET / HTTP/1")
-		test("GET / HTTP/2.0")
-		test("GET / HTTP/1.1\nHeader: value") -- missing \r
+		test("GET") -- no \r\n
+		test("\r\nGET") -- no \r\n with preceeding \r\n
+		test("invalid request line\r\n")
+		test(" / HTTP/1.1\r\n")
+		test("\r\n / HTTP/1.1\r\n")
+		test("HTTP/1.1\r\n")
+		test("GET HTTP/1.0\r\n")
+		test("GET  HTTP/1.0\r\n")
+		test("GET HTTP/1.0\r\n")
+		test("GET / HTP/1.1\r\n")
+		test("GET / HTTP 1.1\r\n")
+		test("GET / HTTP/1\r\n")
+		test("GET / HTTP/2.0\r\n")
+		test("GET / HTTP/1.1\nHeader: value\r\n") -- missing \r
 	end)
 	it(":read_request_line should allow a leading CRLF", function()
 		local function test(chunk)
@@ -142,6 +144,40 @@ describe("low level http 1 connection operations", function()
 		end
 		test("\r\nGET / HTTP/1.1\r\n")
 	end)
+	describe("overlong lines", function()
+		it(":read_request_line", function()
+			local s, c = new_pair(1.1)
+			s = s:take_socket()
+			assert(s:xwrite(("a"):rep(10000), "n"))
+			assert.same(ce.EILSEQ, select(3, c:read_request_line(TEST_TIMEOUT)))
+			s:close()
+			c:close()
+		end)
+		it(":read_status_line", function()
+			local s, c = new_pair(1.1)
+			s = s:take_socket()
+			assert(s:xwrite(("a"):rep(10000), "n"))
+			assert.same(ce.EILSEQ, select(3, c:read_status_line(TEST_TIMEOUT)))
+			s:close()
+			c:close()
+		end)
+		it(":read_header", function()
+			local s, c = new_pair(1.1)
+			s = s:take_socket()
+			assert(s:xwrite(("a"):rep(10000), "n"))
+			assert.same(ce.EILSEQ, select(3, c:read_header(TEST_TIMEOUT)))
+			s:close()
+			c:close()
+		end)
+		it(":read_body_chunk", function()
+			local s, c = new_pair(1.1)
+			s = s:take_socket()
+			assert(s:xwrite(("a"):rep(10000), "n"))
+			assert.same(ce.EILSEQ, select(3, c:read_body_chunk(TEST_TIMEOUT)))
+			s:close()
+			c:close()
+		end)
+	end)
 	it("status line should round trip", function()
 		local function test(req_version, req_status, req_reason)
 			local s, c = new_pair(req_version)
@@ -494,6 +530,49 @@ describe("low level http 1 connection operations", function()
 		s:close()
 		c:close()
 	end)
+	it(":read_body_chunk fails on invalid chunk", function()
+		local function test(chunk, expected_errno)
+			local s, c = new_pair(1.1)
+			s = s:take_socket()
+			assert(s:xwrite(chunk, "n", TEST_TIMEOUT))
+			s:close()
+			local data, _, errno = c:read_body_chunk(TEST_TIMEOUT)
+			assert.same(nil, data)
+			assert.same(expected_errno, errno)
+			c:close()
+		end
+		test("", nil)
+		test("5", ce.EILSEQ)
+		test("5\r", ce.EILSEQ)
+		test("fffffffffffffff\r\n", ce.E2BIG)
+		test("not a number\r\n", ce.EILSEQ)
+		test("4\r\n1", ce.EILSEQ)
+		test("4\r\nfour\n", ce.EILSEQ)
+		test("4\r\nlonger than four", ce.EILSEQ)
+		test("4\r\nfour\nmissing \r", ce.EILSEQ)
+	end)
+	it(":read_body_chunk is cqueues thread-safe", function()
+		local s, c = new_pair(1.1)
+		s = s:take_socket()
+		local cq = cqueues.new()
+		cq:wrap(function()
+			local chunk = assert(c:read_body_chunk())
+			assert.same("bytes", chunk)
+		end)
+		cq:wrap(function()
+			assert(s:xwrite("5\r\n", "bn"))
+			cqueues.sleep(0.001) -- let other thread block on reading chunk body
+			assert(s:xwrite("chars\r\n", "bn"))
+			local chunk = assert(c:read_body_chunk())
+			assert.same("chars", chunk)
+			-- send a 2nd frame
+			assert(s:xwrite("5\r\nbytes\r\n", "bn"))
+			s:close()
+		end)
+		assert_loop(cq, TEST_TIMEOUT)
+		assert.truthy(cq:empty())
+		c:close()
+	end)
 end)
 describe("high level http1 connection operations", function()
 	local h1_connection = require "http.h1_connection"
