@@ -30,8 +30,9 @@ describe("http1 stream", function()
 		local stream = client:new_stream()
 		client:shutdown()
 		local headers = new_headers()
-		headers:append(":authority", "myauthority")
 		headers:append(":method", "GET")
+		headers:append(":scheme", "http")
+		headers:append(":authority", "myauthority")
 		headers:append(":path", "/a")
 		assert.same(ce.EPIPE, select(3, stream:write_headers(headers, true)))
 		client:close()
@@ -43,8 +44,9 @@ describe("http1 stream", function()
 		cq:wrap(function()
 			local stream = client:new_stream()
 			local req_headers = new_headers()
-			req_headers:append(":authority", "myauthority")
 			req_headers:append(":method", "GET")
+			req_headers:append(":scheme", "http")
+			req_headers:append(":authority", "myauthority")
 			req_headers:append(":path", "/a")
 			assert(stream:write_headers(req_headers, true))
 			local res_headers = assert(stream:get_headers())
@@ -91,8 +93,9 @@ describe("http1 stream", function()
 		local server, client = new_pair(1.1)
 		local stream = client:new_stream()
 		local headers = new_headers()
-		headers:append(":authority", "myauthority")
 		headers:append(":method", "GET")
+		headers:append(":scheme", "http")
+		headers:append(":authority", "myauthority")
 		headers:append(":path", "/a")
 		assert(stream:write_headers(headers, true))
 		local cq = cqueues.new():wrap(function()
@@ -109,8 +112,9 @@ describe("http1 stream", function()
 		cq:wrap(function()
 			local stream = client:new_stream()
 			local req_headers = new_headers()
-			req_headers:append(":authority", "myauthority")
 			req_headers:append(":method", "GET")
+			req_headers:append(":scheme", "http")
+			req_headers:append(":authority", "myauthority")
 			req_headers:append(":path", "/a")
 			assert(stream:write_headers(req_headers, true))
 			local res_headers = assert(stream:get_headers())
@@ -135,8 +139,9 @@ describe("http1 stream", function()
 		cq:wrap(function()
 			local stream = client:new_stream()
 			local req_headers = new_headers()
-			req_headers:append(":authority", "myauthority")
 			req_headers:append(":method", "GET")
+			req_headers:append(":scheme", "http")
+			req_headers:append(":authority", "myauthority")
 			req_headers:append(":path", "/a")
 			assert(stream:write_headers(req_headers, true))
 			assert(stream:get_headers())
@@ -166,8 +171,9 @@ describe("http1 stream", function()
 		cq:wrap(function()
 			local stream = client:new_stream()
 			local headers = new_headers()
-			headers:append(":authority", "myauthority")
 			headers:append(":method", "GET")
+			headers:append(":scheme", "http")
+			headers:append(":authority", "myauthority")
 			headers:append(":path", "/a")
 			headers:append("transfer-encoding", "chunked")
 			assert(stream:write_headers(headers, false))
@@ -217,8 +223,9 @@ describe("http1 stream", function()
 		cq:wrap(function()
 			local stream = client:new_stream()
 			local headers = new_headers()
-			headers:append(":authority", "myauthority")
 			headers:append(":method", "GET")
+			headers:append(":scheme", "http")
+			headers:append(":authority", "myauthority")
 			headers:append(":path", "/a")
 			headers:append("transfer-encoding", "chunked")
 			assert(stream:write_headers(headers, false))
@@ -248,8 +255,9 @@ describe("http1 stream", function()
 			do
 				local stream = client:new_stream()
 				local headers = new_headers()
-				headers:append(":authority", "myauthority")
 				headers:append(":method", "GET")
+				headers:append(":scheme", "http")
+				headers:append(":authority", "myauthority")
 				headers:append(":path", "/a")
 				headers:append("content-length", "100")
 				assert(stream:write_headers(headers, false))
@@ -258,8 +266,9 @@ describe("http1 stream", function()
 			do
 				local stream = client:new_stream()
 				local headers = new_headers()
-				headers:append(":authority", "myauthority")
 				headers:append(":method", "GET")
+				headers:append(":scheme", "http")
+				headers:append(":authority", "myauthority")
 				headers:append(":path", "/b")
 				headers:append("content-length", "0")
 				assert(stream:write_headers(headers, true))
@@ -313,8 +322,9 @@ describe("http1 stream", function()
 			if client_sync then client_sync:wait() end
 			local a = client:new_stream()
 			local ah = new_headers()
-			ah:append(":authority", "myauthority")
 			ah:append(":method", "GET")
+			ah:append(":scheme", "http")
+			ah:append(":authority", "myauthority")
 			ah:append(":path", "/a")
 			assert(a:write_headers(ah, true))
 		end)
@@ -322,8 +332,9 @@ describe("http1 stream", function()
 			client_sync:signal(); client_sync = nil;
 			local b = client:new_stream()
 			local bh = new_headers()
-			bh:append(":authority", "myauthority")
 			bh:append(":method", "POST")
+			bh:append(":scheme", "http")
+			bh:append(":authority", "myauthority")
 			bh:append(":path", "/b")
 			assert(b:write_headers(bh, false))
 			cqueues.sleep(0.01)
@@ -332,8 +343,9 @@ describe("http1 stream", function()
 		cq:wrap(function()
 			local c = client:new_stream()
 			local ch = new_headers()
-			ch:append(":authority", "myauthority")
 			ch:append(":method", "GET")
+			ch:append(":scheme", "http")
+			ch:append(":authority", "myauthority")
 			ch:append(":path", "/c")
 			assert(c:write_headers(ch, true))
 		end)
@@ -375,8 +387,9 @@ describe("http1 stream", function()
 
 			do
 				local h = new_headers()
-				h:append(":authority", "myauthority")
 				h:append(":method", "POST")
+				h:append(":scheme", "http")
+				h:append(":authority", "myauthority")
 				h:append(":path", "/")
 				h:upsert("id", "a")
 				assert(a:write_headers(h, false))
@@ -443,8 +456,9 @@ describe("http1 stream", function()
 		cq:wrap(function()
 			local a = client:new_stream()
 			local h = new_headers()
-			h:append(":authority", "myauthority")
 			h:append(":method", "POST")
+			h:append(":scheme", "http")
+			h:append(":authority", "myauthority")
 			h:append(":path", "/a")
 			h:append("expect", "100-continue")
 			assert(a:write_headers(h, false))
@@ -476,8 +490,9 @@ describe("http1 stream", function()
 		cq:wrap(function()
 			local a = client:new_stream()
 			local h = new_headers()
-			h:append(":authority", "myauthority")
 			h:append(":method", "GET")
+			h:append(":scheme", "http")
+			h:append(":authority", "myauthority")
 			h:append(":path", "/")
 			assert(a:write_headers(h, true))
 		end)
