@@ -92,6 +92,7 @@ describe("http.websocket", function()
 		end
 		local correct_headers = http_headers.new()
 		correct_headers:append(":method", "GET")
+		correct_headers:append(":scheme", "http")
 		correct_headers:append(":authority", "example.com")
 		correct_headers:append(":path", "/")
 		correct_headers:append("upgrade", "websocket")
@@ -375,6 +376,7 @@ describe("http.websocket module two sided tests", function()
 			port = 0;
 			onstream = function(s, stream)
 				local headers = assert(stream:get_headers())
+				assert.same("http", headers:get(":scheme"))
 				local ws = websocket.new_from_stream(stream, headers)
 				assert(ws:accept())
 				assert(ws:close())
